@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2012-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -31,8 +31,10 @@ public:
     explicit BalsaAddressBook(const QString &filename, ImportWizard *parent);
     ~BalsaAddressBook();
 
+    void importAddressBook();
 private:
     void readAddressBook(const KConfigGroup &grp);
+    QString mFileName;
 };
 
 #endif // BalsaAddressBook_H
