@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2012-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -31,11 +31,13 @@ public:
     explicit OperaSettings(const QString &filename, ImportWizard *parent);
     ~OperaSettings();
 
+    void importSettings();
 private:
     void readAccount(const KConfigGroup &grp);
     void readTransport(const KConfigGroup &grp);
     void readGlobalAccount(const KConfigGroup &grp);
     void readIdentity(const KConfigGroup &grp);
+    QString mFileName;
 };
 
 #endif // OPERASETTINGS_H
